@@ -1,6 +1,6 @@
 var Client = require('node-rest-client').Client;
 const readline = require('readline');
-const uuidv1 = require('uuid/v1');
+const { v1: uuidv1 } = require('uuid')
 
 const PRODUCTID='904b7e35-33c8-45c6-8fd1-f5807b68f8e6';
 const PRODUCTSECRET='bKN0NYfkkVHQx78A8rFCjS0z';
